emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] master 0e10b6f: Spelling fixes (Bug#10068)


From: Paul Eggert
Subject: [Emacs-diffs] master 0e10b6f: Spelling fixes (Bug#10068)
Date: Sun, 4 Mar 2018 20:39:58 -0500 (EST)

branch: master
commit 0e10b6fce7568077797c5a16cd2a584a8dcba46e
Author: Paul Eggert <address@hidden>
Commit: Paul Eggert <address@hidden>

    Spelling fixes (Bug#10068)
    
    * lisp/gnus/gnus-score.el (gnus-score-find-favorite-words):
    Rename from gnus-score-find-favourite-words.
    * lisp/hfy-cmap.el (hfy-fallback-color-map)
    (hfy-rgb-txt-color-map, hfy-fallback-color-values):
    * lisp/htmlfontify.el (hfy-color-vals, hfy-color):
    Rename from names that used 'colour' instead of 'color'.
---
 doc/misc/gnus.texi      |  4 ++--
 etc/NEWS                | 10 ++++++++++
 lisp/gnus/gnus-score.el |  7 +++++--
 lisp/gnus/gnus-sum.el   |  2 +-
 lisp/hfy-cmap.el        | 35 ++++++++++++++++++++++-------------
 lisp/htmlfontify.el     | 48 +++++++++++++++++++++++++-----------------------
 lisp/net/tramp-adb.el   |  2 +-
 7 files changed, 66 insertions(+), 42 deletions(-)

diff --git a/doc/misc/gnus.texi b/doc/misc/gnus.texi
index 8a0b631..cc4b234 100644
--- a/doc/misc/gnus.texi
+++ b/doc/misc/gnus.texi
@@ -19471,8 +19471,8 @@ score file and edit it.
 
 @item V w
 @kindex V w @r{(Summary)}
address@hidden gnus-score-find-favourite-words
-List words used in scoring (@code{gnus-score-find-favourite-words}).
address@hidden gnus-score-find-favorite-words
+List words used in scoring (@code{gnus-score-find-favorite-words}).
 
 @item V R
 @kindex V R @r{(Summary)}
diff --git a/etc/NEWS b/etc/NEWS
index 08c7e7e..c998ad6 100644
--- a/etc/NEWS
+++ b/etc/NEWS
@@ -142,6 +142,16 @@ This can be controlled by the new 
`ecomplete-sort-predicate' variable.
 *** The 'ecompleterc' file is now placed in ~/.emacs.d/ecompleterc by default
 Of course it will still find it if you have it in ~/.ecompleterc
 
+** Gnus
+*** The function 'gnus-score-find-favorite-words' has been renamed
+from 'gnus-score-find-favourite-words'.
+
+** Htmlfontify
+*** The functions 'hfy-color', 'hfy-color-vals' and
+'hfy-fallback-color-values' and the variables 'hfy-fallback-color-map'
+and 'hfy-rgb-txt-color-map' have been renamed from names that used
+'colour' instead of 'color'.
+
 ** Smtpmail
 Authentication mechanisms can be added via external packages, by
 defining new cl-defmethod of smtpmail-try-auth-method.
diff --git a/lisp/gnus/gnus-score.el b/lisp/gnus/gnus-score.el
index ec07d1a..ad11ff4 100644
--- a/lisp/gnus/gnus-score.el
+++ b/lisp/gnus/gnus-score.el
@@ -514,7 +514,7 @@ of the last successful match.")
   "f" gnus-score-edit-file
   "F" gnus-score-flush-cache
   "t" gnus-score-find-trace
-  "w" gnus-score-find-favourite-words)
+  "w" gnus-score-find-favorite-words)
 
 ;; Summary score file commands
 
@@ -2517,7 +2517,7 @@ the score file and its full name, including the 
directory.")
     (set-buffer gnus-summary-buffer)
     (setq gnus-newsgroup-scored old-scored)))
 
-(defun gnus-score-find-favourite-words ()
+(defun gnus-score-find-favorite-words ()
   "List words used in scoring."
   (interactive)
   (let ((alists (gnus-score-load-files (gnus-all-score-files)))
@@ -2553,6 +2553,9 @@ the score file and its full name, including the 
directory.")
        (pop rules))
       (goto-char (point-min))
       (gnus-configure-windows 'score-words))))
+(define-obsolete-function-alias
+  'gnus-score-find-favourite-words
+  'gnus-score-find-favorite-words "27.1")
 
 (defun gnus-summary-rescore ()
   "Redo the entire scoring process in the current summary."
diff --git a/lisp/gnus/gnus-sum.el b/lisp/gnus/gnus-sum.el
index a28c00b..468f2b1 100644
--- a/lisp/gnus/gnus-sum.el
+++ b/lisp/gnus/gnus-sum.el
@@ -2370,7 +2370,7 @@ increase the score of each group you read."
          ["Edit current score file" gnus-score-edit-current-scores t]
          ["Edit score file..." gnus-score-edit-file t]
          ["Trace score" gnus-score-find-trace t]
-         ["Find words" gnus-score-find-favourite-words t]
+         ["Find words" gnus-score-find-favorite-words t]
          ["Rescore buffer" gnus-summary-rescore t]
          ["Increase score..." gnus-summary-increase-score t]
          ["Lower score..." gnus-summary-lower-score t]))))
diff --git a/lisp/htmlfontify.el b/lisp/htmlfontify.el
index dfa6bde..799da86 100644
--- a/lisp/htmlfontify.el
+++ b/lisp/htmlfontify.el
@@ -584,22 +584,23 @@ therefore no longer care about) will be invalid at any 
time.\n
       (if (memq elt set-b) (setq interq (cons elt interq))))
     interq))
 
-(defun hfy-colour-vals (colour)
-  "Where COLOUR is a color name or #XXXXXX style triplet, return a
+(defun hfy-color-vals (color)
+  "Where COLOR is a color name or #XXXXXX style triplet, return a
 list of three (16 bit) rgb values for said color.\n
-If a window system is unavailable, calls `hfy-fallback-colour-values'."
-  (if (string-match hfy-triplet-regex colour)
+If a window system is unavailable, calls `hfy-fallback-color-values'."
+  (if (string-match hfy-triplet-regex color)
       (mapcar
-       (lambda (x) (* (string-to-number (match-string x colour) 16) 257))
+       (lambda (x) (* (string-to-number (match-string x color) 16) 257))
        '(1 2 3))
-    ;;(message ">> %s" colour)
+    ;;(message ">> %s" color)
     (if window-system
         (if (fboundp 'color-values)
-            (color-values colour)
+            (color-values color)
           ;;(message "[%S]" window-system)
-          (x-color-values colour))
+          (x-color-values color))
       ;; blarg - tty colors are no good - go fetch some X colors:
-      (hfy-fallback-colour-values colour))))
+      (hfy-fallback-color-values color))))
+(define-obsolete-function-alias 'hfy-colour-vals 'hfy-color-vals "27.1")
 
 (defvar hfy-cperl-mode-kludged-p nil)
 
@@ -738,7 +739,7 @@ FILE is the name of the file being rendered, in case it is 
needed."
   "Replace the end of a CSS style declaration STYLE-STRING with the contents
 of the variable `hfy-src-doc-link-style', removing text matching the regex
 `hfy-src-doc-link-unstyle' first, if necessary."
-  ;;(message "hfy-colour-vals");;DBUG
+  ;;(message "hfy-color-vals");;DBUG
   (if (string-match hfy-src-doc-link-unstyle style-string)
       (setq style-string (replace-match "" 'fixed-case 'literal style-string)))
   (if (and (not (string-match hfy-src-doc-link-style style-string))
@@ -751,19 +752,19 @@ of the variable `hfy-src-doc-link-style', removing text 
matching the regex
 
 ;; utility functions - cast emacs style specification values into their
 ;; css2 equivalents:
-(defun hfy-triplet (colour)
-  "Takes a COLOUR name (string) and return a CSS rgb(R, G, B) triplet string.
+(defun hfy-triplet (color)
+  "Takes a COLOR name (string) and return a CSS rgb(R, G, B) triplet string.
 Uses the definition of \"white\" to map the numbers to the 0-255 range, so
 if you've redefined white, (esp. if you've redefined it to have a triplet
 member lower than that of the color you are processing) strange things
 may happen."
-  ;;(message "hfy-colour-vals");;DBUG
+  ;;(message "hfy-color-vals");;DBUG
   ;; TODO?  Can we do somehow do better than this?
   (cond
-   ((equal colour "unspecified-fg") (setq colour "black"))
-   ((equal colour "unspecified-bg") (setq colour "white")))
-  (let ((white (mapcar (lambda (I) (float (1+ I))) (hfy-colour-vals "white")))
-        (rgb16 (mapcar (lambda (I) (float (1+ I))) (hfy-colour-vals  colour))))
+   ((equal color "unspecified-fg") (setq color "black"))
+   ((equal color "unspecified-bg") (setq color "white")))
+  (let ((white (mapcar (lambda (I) (float (1+ I))) (hfy-color-vals "white")))
+        (rgb16 (mapcar (lambda (I) (float (1+ I))) (hfy-color-vals  color))))
     (if rgb16
         ;;(apply 'format "rgb(%d, %d, %d)"
         ;; Use #rrggbb instead, it is smaller
@@ -774,8 +775,9 @@ may happen."
                        '(0 1 2))))))
 
 (defun hfy-family (family) (list (cons "font-family"  family)))
-(defun hfy-bgcol  (colour) (list (cons "background"   (hfy-triplet colour))))
-(defun hfy-colour (colour) (list (cons "color"        (hfy-triplet colour))))
+(defun hfy-bgcol  (color) (list (cons "background"   (hfy-triplet color))))
+(defun hfy-color (color) (list (cons "color"        (hfy-triplet color))))
+(define-obsolete-function-alias 'hfy-colour 'hfy-color "27.1")
 (defun hfy-width  (width)  (list (cons "font-stretch" (symbol-name  width))))
 
 (defcustom hfy-font-zoom 1.05
@@ -825,17 +827,17 @@ regular specifiers."
       (let ((tag (car  spec))
             (val (cadr spec)))
         (cons (cl-case tag
-                (:color (cons "colour" val))
+                (:color (cons "color" val))
                 (:width (cons "width"  val))
                 (:style (cons "style"  val)))
               (hfy-box-to-border-assoc (cddr spec))))))
 
 (defun hfy-box-to-style (spec)
   (let* ((css (hfy-box-to-border-assoc  spec))
-         (col (cdr      (assoc "colour" css)))
+         (col (cdr      (assoc "color" css)))
          (s   (cdr      (assoc "style"  css))))
     (list
-     (if col (cons "border-color" (cdr (assoc "colour" css))))
+     (if col (cons "border-color" (cdr (assoc "color" css))))
      (cons "border-width" (format "%dpx" (or (cdr (assoc "width" css)) 1)))
      (cons "border-style" (cl-case s
                             (released-button "outset")
@@ -1014,7 +1016,7 @@ merged by the user - `hfy-flatten-style' should do this."
                        (:width          (hfy-width     val))
                        (:weight         (hfy-weight    val))
                        (:slant          (hfy-slant     val))
-                       (:foreground     (hfy-colour    val))
+                       (:foreground     (hfy-color     val))
                        (:background     (hfy-bgcol     val))
                        (:box            (hfy-box       val))
                        (:height         (hfy-size      val))
diff --git a/lisp/net/tramp-adb.el b/lisp/net/tramp-adb.el
index 7ac61b8..7a0ea71 100644
--- a/lisp/net/tramp-adb.el
+++ b/lisp/net/tramp-adb.el
@@ -464,7 +464,7 @@ pass to the OPERATION."
     (cond
      ;; Support Android derived systems where "ls" command is provided
      ;; by GNU Coreutils. Force "ls" to print one column and set
-     ;; time-style to imitate other "ls" flavours.
+     ;; time-style to imitate other "ls" flavors.
      ((tramp-adb-send-command-and-check
        vec "ls --time-style=long-iso /dev/null")
       "ls -1 --time-style=long-iso")



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/hfy-cmap.el b/lisp/hfy-cmap.el
index 6dea345..4ec24ce 100644
--- a/lisp/hfy-cmap.el
+++ b/lisp/hfy-cmap.el
@@ -1,15 +1,15 @@
 ;;; hfy-cmap.el --- Fallback colour name -> rgb mapping for `htmlfontify'
 
 ;; Copyright (C) 2002-2003, 2009-2018 Free Software Foundation, Inc.
 
 ;; Emacs Lisp Archive Entry
 ;; Package: htmlfontify
 ;; Filename: hfy-cmap.el
 ;; Keywords: colour, rgb
 ;; Author: Vivek Dasmohapatra <address@hidden>
 ;; Maintainer: Vivek Dasmohapatra <address@hidden>
 ;; Created: 2002-01-20
 ;; Description: fallback code for colour name -> rgb mapping
 ;; URL: http://rtfm.etla.org/emacs/htmlfontify/
 ;; Last-Updated: Sat 2003-02-15 03:49:32 +0000
 
@@ -32,7 +32,7 @@
 
 ;;; Code:
 
-(defconst hfy-fallback-colour-map
+(defconst hfy-fallback-color-map
   '(("snow"                    65535 64250 64250)
     ("ghost white"             63736 63736 65535)
     ("GhostWhite"              63736 63736 65535)
@@ -785,8 +785,14 @@
     ("DarkRed"                 35723     0     0)
     ("light green"             37008 61166 37008)
     ("LightGreen"              37008 61166 37008)) )
+(define-obsolete-variable-alias
+  'hfy-fallback-colour-map
+  'hfy-fallback-color-map "27.1")
 
-(defvar hfy-rgb-txt-colour-map nil)
+(defvar hfy-rgb-txt-color-map nil)
+(define-obsolete-variable-alias
+  'hfy-rgb-txt-colour-map
+  'hfy-rgb-txt-color-map "27.1")
 
 (defvar hfy-rgb-load-path
   (list "/etc/X11"
@@ -806,8 +812,8 @@
 (defun htmlfontify-load-rgb-file (&optional file)
   "Load an X11 style rgb.txt FILE.
 Search `hfy-rgb-load-path' if FILE is not specified.
-Loads the variable `hfy-rgb-txt-colour-map', which is used by
-`hfy-fallback-colour-values'."
+Loads the variable `hfy-rgb-txt-color-map', which is used by
+`hfy-fallback-color-values'."
   (interactive
    (list
     (read-file-name "rgb.txt (equivalent) file: " "" nil t (hfy-rgb-file))))
@@ -822,25 +828,28 @@ Loads the variable `hfy-rgb-txt-colour-map', which is 
used by
          (htmlfontify-unload-rgb-file)
          (while (/= end-of-rgb 1)
            (if (looking-at hfy-rgb-regex)
-               (setq hfy-rgb-txt-colour-map
+               (setq hfy-rgb-txt-color-map
                      (cons (list (match-string 4)
                                  (string-to-number (match-string 1))
                                  (string-to-number (match-string 2))
                                  (string-to-number (match-string 3)))
-                           hfy-rgb-txt-colour-map)) )
+                           hfy-rgb-txt-color-map)) )
            (setq end-of-rgb (forward-line)))
          (kill-buffer rgb-buffer)))))
 
 (defun htmlfontify-unload-rgb-file ()
   "Unload the current color name -> rgb translation map."
   (interactive)
-  (setq hfy-rgb-txt-colour-map nil))
+  (setq hfy-rgb-txt-color-map nil))
 
 ;;;###autoload
-(defun hfy-fallback-colour-values (colour-string)
+(defun hfy-fallback-color-values (color-string)
   "Use a fallback method for obtaining the rgb values for a color."
-  (cdr (assoc-string colour-string (or hfy-rgb-txt-colour-map
-                                       hfy-fallback-colour-map))) )
+  (cdr (assoc-string color-string (or hfy-rgb-txt-color-map
+                                     hfy-fallback-color-map))) )
+(define-obsolete-function-alias
+  'hfy-fallback-colour-values
+  'hfy-fallback-color-values "27.1")
 
 (provide 'hfy-cmap)
 
@@ -1,15 +1,15 @@
-;;; hfy-cmap.el --- Fallback colour name -> rgb mapping for `htmlfontify'
+;;; hfy-cmap.el --- Fallback color name -> rgb mapping for `htmlfontify'
 
 ;; Copyright (C) 2002-2003, 2009-2018 Free Software Foundation, Inc.
@@ -1,15 +1,15 @@
 ;; Package: htmlfontify
 ;; Filename: hfy-cmap.el
-;; Keywords: colour, rgb
+;; Keywords: color, rgb
 ;; Author: Vivek Dasmohapatra <address@hidden>
 ;; Maintainer: Vivek Dasmohapatra <address@hidden>
@@ -1,15 +1,15 @@
 ;; Maintainer: Vivek Dasmohapatra <address@hidden>
 ;; Created: 2002-01-20
-;; Description: fallback code for colour name -> rgb mapping
+;; Description: fallback code for color name -> rgb mapping
 ;; URL: http://rtfm.etla.org/emacs/htmlfontify/
 ;; Last-Updated: Sat 2003-02-15 03:49:32 +0000